==> basic-feign-airport-1.0.2-20250806.074207-1-sources.jar: com/bizvane/basic/feign/model/vo/TSysAccountVo.java <==
package com.bizvane.basic.feign.model.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>
 * 用户账号
 * </p>
 */
@Getter
@Setter
public class TSysAccountVo implements Serializable {

    private static final long serialVersionUID=1L;

    @ApiModelProperty(value = "pkid")
    private Long id;

    @ApiModelProperty(value = "机场编号（多个逗号隔开）")
    private String airportCode;

    @ApiModelProperty(value = "账户code")
    private String accountCode;

    @ApiModelProperty(value = "手机")
    private String phone;

    @ApiModelProperty(value = "姓名")
    private String name;

    @ApiModelProperty(value = "航司code")
    private String airlinesCode;

    @ApiModelProperty(value = "小程序-所属机场code")
    private String airportCodeApplet;

    @ApiModelProperty(value = "组织code")
    private String orgCode;

    @ApiModelProperty(value = "管辖商户code（多个逗号隔开）")
    private String merchantCode;

    @ApiModelProperty(value = "状态：0=禁用；1=启用")
    private Boolean status;

    @ApiModelProperty(value = "强制修改密码标志位：1=需要，0=不需要")
    private Boolean resetPassword;

    @ApiModelProperty(value = "使用系统(1-会员运营平台 2-小程序工作台)", notes = "多个逗号隔开")
    private String useSystem;

    @ApiModelProperty(value = "使用功能（1-航延发放 2-管家服务 3-商品自提 4-卡券核销）", notes = "多个逗号隔开")
    private String useFunction;

    @ApiModelProperty("管辖核销商户code (多个逗号隔开)")
    private String cancelMerchantCode;

    @ApiModelProperty(value = "备注")
    private String remark;

    @ApiModelProperty(value = "创建人id")
    private String createUserCode;

    @ApiModelProperty(value = "创建人")
    private String createUserName;

    @ApiModelProperty(value = "创建日期")
    private Date createDate;

    @ApiModelProperty(value = "修改人id")
    private String modifiedUserCode;

    @ApiModelProperty(value = "修改人")
    private String modifiedUserName;

    @ApiModelProperty(value = "修改时间")
    private Date modifiedDate;

    @ApiModelProperty(value = "上次登录时间")
    private Date lastLoginTime;

    private Boolean valid;

    private Date passwordExpiryTime;


}

==> basic-feign-airport-20241115.110816-19-sources.jar: com/bizvane/basic/feign/model/vo/TSysAccountVo.java <==
package com.bizvane.basic.feign.model.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>
 * 用户账号
 * </p>
 */
@Getter
@Setter
public class TSysAccountVo implements Serializable {

    private static final long serialVersionUID=1L;

    @ApiModelProperty(value = "pkid")
    private Long id;

    @ApiModelProperty(value = "机场编号")
    private String airportCode;

    @ApiModelProperty(value = "账户code")
    private String accountCode;

    @ApiModelProperty(value = "手机")
    private String phone;

    @ApiModelProperty(value = "姓名")
    private String name;

    @ApiModelProperty(value = "航司code")
    private String airlinesCode;

    @ApiModelProperty(value = "组织code")
    private String orgCode;

    @ApiModelProperty(value = "状态：0=禁用；1=启用")
    private Boolean status;

    @ApiModelProperty(value = "强制修改密码标志位：1=需要，0=不需要")
    private Boolean resetPassword;

    @ApiModelProperty(value = "使用系统(1-会员运营平台 2-小程序工作台)", notes = "多个逗号隔开")
    private String useSystem;

    @ApiModelProperty(value = "使用功能（1-航延发放 2-管家服务 3-商品自提）", notes = "多个逗号隔开")
    private String useFunction;

    @ApiModelProperty(value = "备注")
    private String remark;

    @ApiModelProperty(value = "创建人id")
    private String createUserCode;

    @ApiModelProperty(value = "创建人")
    private String createUserName;

    @ApiModelProperty(value = "创建日期")
    private Date createDate;

    @ApiModelProperty(value = "修改人id")
    private String modifiedUserCode;

    @ApiModelProperty(value = "修改人")
    private String modifiedUserName;

    @ApiModelProperty(value = "修改时间")
    private Date modifiedDate;

    @ApiModelProperty(value = "上次登录时间")
    private Date lastLoginTime;

    private Boolean valid;


}
